# This script searches for installed Apache sources and determines paths to includes and libraries.
# Script is used in building RPM for HTTPD24 Apache.
# Returns next variables for each version of Apache:
# for Apache 2.4: APACHE2_4_FOUND    APACHE_HTTPD_INCLUDE_DIR    APACHE_APR_INCLUDE_DIR    APACHE_APRUTIL_INCLUDE_DIR    APACHE_APR_LIBRARY    APACHE_HTTPD_MODULES



# --- Apache 2.4 ---------------------------------------------------------------------------------------------------------------------------
SET(APR_NAME apr-1)
SET(APRUTIL_NAME aprutil-1)

# APR first.
FIND_PATH (APACHE_APR_INCLUDE_DIR 
   NAMES 
      apr.h
   PATHS 
      /opt/rh/httpd24/root/usr/include/apr-1
      /usr/include/apr-1
)

FIND_LIBRARY (APACHE_APR_LIBRARY 
   NAMES 
      ${APR_NAME}
   PATHS 
      /opt/rh/httpd24/root/usr/lib64
      /opt/rh/httpd24/root/usr/lib
      /usr/lib64
      /usr/lib
)



# Next,  APRUTIL.
FIND_PATH (APACHE_APRUTIL_INCLUDE_DIR 
   NAMES 
      apu.h
   PATHS
      /opt/rh/httpd24/root/usr/include/apr-1
      /usr/include/apr-1
)

FIND_LIBRARY (APACHE_APRUTIL_LIBRARY 
   NAMES 
      ${APRUTIL_NAME}
   PATHS 
      /opt/rh/httpd24/root/usr/lib64
      /opt/rh/httpd24/root/usr/lib
      /usr/lib64
      /usr/lib
)



# Next,  HTTPD.
FIND_PATH (APACHE_HTTPD_INCLUDE_DIR 
   NAMES 
      httpd.h
   PATHS
      /opt/rh/httpd24/root/usr/include/httpd

)

# Next, bin directory
FIND_PATH (APACHE_HTTPD_BIN
   NAMES
      apachectl
   PATHS
      /opt/rh/httpd24/root/usr/sbin
)

# Next, module directory
FIND_PATH (APACHE_HTTPD_MODULES
NAMES
    mod_alias.so
PATHS
    /opt/rh/httpd24/root/etc/httpd/modules
)

# *** This code is for status messages output only ***************************************
IF (APACHE_APR_INCLUDE_DIR AND APACHE_APR_LIBRARY)
   SET (APACHE2_4_APR_FOUND TRUE)
   MESSAGE (STATUS "Found Apache Portable Runtime: ${APACHE_APR_INCLUDE_DIR}, ${APACHE_APR_LIBRARY}")
ELSE (APACHE_APR_INCLUDE_DIR AND APACHE_APR_LIBRARY)
   SET (APACHE2_4_APR_FOUND FALSE)
   MESSAGE (STATUS "Can't find Apache Portable Runtime")
ENDIF (APACHE_APR_INCLUDE_DIR AND APACHE_APR_LIBRARY)

IF (APACHE_APRUTIL_INCLUDE_DIR AND APACHE_APRUTIL_LIBRARY)
   SET(APACHE2_4_APRUTIL_FOUND TRUE)
   MESSAGE (STATUS "Found Apache Portable Runtime Utils: ${APACHE_APRUTIL_INCLUDE_DIR}, ${APACHE_APRUTIL_LIBRARY}")
ELSE (APACHE_APRUTIL_INCLUDE_DIR AND APACHE_APRUTIL_LIBRARY)
   SET(APACHE2_4_APRUTIL_FOUND FALSE)
   MESSAGE (STATUS "Can't find Apache Portable Runtime Utils")
ENDIF (APACHE_APRUTIL_INCLUDE_DIR AND APACHE_APRUTIL_LIBRARY)

IF (APACHE_HTTPD_BIN AND APACHE_HTTPD_MODULES AND APACHE_HTTPD_INCLUDE_DIR)
   SET(APACHE2_4_HTTPD_BIN_FOUND TRUE)
   MESSAGE (STATUS "Found Apache Bin Directory: ${APACHE_HTTPD_BIN}, ${APACHE_HTTPD_MODULES}, ${APACHE_HTTPD_INCLUDE_DIR}")
ELSE (APACHE_HTTPD_BIN AND APACHE_HTTPD_MODULES AND APACHE_HTTPD_INCLUDE_DIR)
   SET(APACHE2_4_HTTPD_BIN_FOUND FALSE)
   MESSAGE (STATUS "Not Found Apache Bin Directory: ${APACHE_HTTPD_BIN}, ${APACHE_HTTPD_MODULES}, ${APACHE_HTTPD_INCLUDE_DIR}")
ENDIF(APACHE_HTTPD_BIN AND APACHE_HTTPD_MODULES AND APACHE_HTTPD_INCLUDE_DIR)
# ****************************************************************************************

# Check if all needed directories are found
IF (APACHE2_4_APR_FOUND AND APACHE2_4_APRUTIL_FOUND AND APACHE2_4_HTTPD_BIN_FOUND)
  SET (APACHE2_4_FOUND TRUE)
  MESSAGE (STATUS "Found Apache2.4: ${APACHE_HTTPD_INCLUDE_DIR}")

ELSE (APACHE2_4_APR_FOUND AND APACHE2_4_APRUTIL_FOUND AND APACHE2_4_HTTPD_BIN_FOUND)
  SET (APACHE2_4_FOUND FALSE)
  MESSAGE (STATUS "Can't find Apache2.4: ${APACHE_HTTPD_INCLUDE_DIR}")

ENDIF (APACHE2_4_APR_FOUND AND APACHE2_4_APRUTIL_FOUND AND APACHE2_4_HTTPD_BIN_FOUND)
